@@ -31,6 +31,8 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'course.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'offering.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'member.php');
@@ -38,7 +40,7 @@ require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models'
 /**
  * Courses controller class for managing membership and course info
  */
-class CoursesControllerStudents extends \Hubzero\Component\AdminController
+class CoursesControllerStudents extends Hubzero_Controller
 {
 	/**
 	 * Displays a list of courses
@@ -48,7 +50,7 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 	public function displayTask()
 	{
 		// Get configuration
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$config = JFactory::getConfig();
 
 		// Incoming
@@ -65,7 +67,6 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 		);
 
 		$this->view->offering = CoursesModelOffering::getInstance($this->view->filters['offering']);
-		$this->view->filters['offering_id'] = $this->view->filters['offering'];
 		/*if (!$this->view->offering->exists())
 		{
 			$this->setRedirect(
@@ -93,44 +94,15 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 			0,
 			'int'
 		);
+		$this->view->filters['role'] = 'student';
 
-		$this->view->filters['start'] = ($this->view->filters['limit'] != 0 ? (floor($this->view->filters['start'] / $this->view->filters['limit']) * $this->view->filters['limit']) : 0);
-		//$this->view->filters['role'] = 'student';
+		$this->view->filters['count'] = true;
 
-		//$this->view->filters['count'] = true;
+		$this->view->total = $this->view->offering->members($this->view->filters);
 
-		/*if (!$this->view->filters['section_id'])
-		{
-			$this->view->filters['section_id'] = array();
-			foreach ($this->view->offering->sections() as $section)
-			{
-				$this->view->filters['section_id'][] = $section->get('id');
-			}
-		}*/
-		if (!$this->view->filters['offering_id'])
-		{
-			$this->view->filters['offering_id'] = null;
-		}
-		if (!$this->view->filters['section_id'])
-		{
-			$this->view->filters['section_id'] = null;
-		}
-		$this->view->filters['student'] = 1;
+		$this->view->filters['count'] = false;
 
-		$tbl = new CoursesTableMember($this->database);
-
-		$this->view->total = $tbl->count($this->view->filters); //$this->view->offering->students($this->view->filters);
-
-		//$this->view->filters['count'] = false;
-
-		$this->view->rows = $tbl->find($this->view->filters); //$this->view->offering->students($this->view->filters);
-		if ($this->view->rows)
-		{
-			foreach ($this->view->rows as $key => $row)
-			{
-				$this->view->rows[$key] = new CoursesModelStudent($row);
-			}
-		}
+		$this->view->rows = $this->view->offering->members($this->view->filters);
 
 		// Initiate paging
 		jimport('joomla.html.pagination');
@@ -205,18 +177,19 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 		else
 		{
 			// Incoming
-			$id = JRequest::getVar('id', array(0));
+			$ids = JRequest::getVar('id', array());
 
 			// Get the single ID we're working with
-			if (is_array($id))
+			if (is_array($ids))
 			{
-				$id = (!empty($id)) ? $id[0] : 0;
+				$id = (!empty($ids)) ? $ids[0] : 0;
+			}
+			else
+			{
+				$id = 0;
 			}
 
-			$course_id  = $this->view->offering->get('course_id');
-			$section_id = $this->view->offering->section()->get('id');
-
-			$this->view->row = CoursesModelStudent::getInstance($id, null, null, null); //, $course_id, $offering, $section_id);
+			$this->view->row = CoursesModelMember::getInstance($id, $offering);
 		}
 
 		$this->view->course = CoursesModelCourse::getInstance($this->view->offering->get('course_id'));
@@ -229,7 +202,6 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 				$this->view->setError($error);
 			}
 		}
-		//getComponentMessage();
 
 		// Output the HTML
 		$this->view->display();
@@ -269,24 +241,12 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 		}
 
 		$offering = JRequest::getInt('offering', 0);
-		if (!$offering && isset($fields['offering_id']))
-		{
-			$offering = $fields['offering_id'];
-		}
-		$offeringObj = CoursesModelOffering::getInstance($offering);
 
-		$c = 0;
 		foreach ($user_ids as $user_id)
 		{
 			if (!is_int($user_id))
 			{
 				$user = JUser::getInstance($user_id);
-				if (!is_object($user))
-				{
-					$this->addComponentMessage(JText::_('COM_COURSES_ERROR_USER_NOTFOUND') . ' ' . $user_id);
-					$this->editTask( );
-					return;
-				}
 				$fields['user_id'] = $user->get('id');
 			}
 			else
@@ -294,45 +254,19 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 				$fields['user_id'] = $user_id;
 			}
 			// Instantiate the model
-			$fields['course_id'] = $offeringObj->get('course_id');
-			//$section_id = $offeringObj->section()->get('id');
-
-			//$model = CoursesModelMember::getInstance($fields['user_id'], $fields['course_id'], $offering, $section_id);
-			$model = CoursesModelMember::getInstance($fields['user_id'], $fields['course_id'], null, null);
-
-			// Is there an existing record and are they a student?
-			if ($model->exists() && !$model->get('student'))
-			{
-				//$this->addComponentMessage(JText::sprintf('User "%s" is a course manager and cannot be added as a student.', $user_id), 'error');
-				JFactory::getApplication()->enqueueMessage(JText::sprintf('COM_COURSES_ERROR_ALREADY_COURSE_MANAGER', $user_id), 'error');
-				continue;
-			}
-			// If the section is the same
-			if ($model->exists() && $model->get('section_id') == $fields['section_id'])
-			{
-				//$this->addComponentMessage(JText::sprintf('User "%s" is already a student of the selected section.', $user_id), 'warning');
-				JFactory::getApplication()->enqueueMessage(JText::sprintf('COM_COURSES_ERROR_ALREADY_STUDENT', $user_id), 'warning');
-				continue;
-			}
-
-			// Ensure it's a new record as the check above
-			// could pull a record for another section
-			$model->set('id', null);
-
-			// Safe to proceed...
+			$model = CoursesModelMember::getInstance($fields['user_id'], $offering);
 
 			// Bind posted data
 			if (!$model->bind($fields))
 			{
-				$this->addComponentMessage($model->getError(), 'error');
+				$this->addComponentMessage($model->getError());
 				$this->editTask($model);
 				return;
 			}
-
 			// Store data
 			if (!$model->store())
 			{
-				$this->addComponentMessage($model->getError(), 'error');
+				$this->addComponentMessage($model->getError());
 				$this->editTask($model);
 				return;
 			}
@@ -349,7 +283,7 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 			// Output messsage and redirect
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&offering=' . $fields['offering_id'] . '&section=' . $fields['section_id'],
-				($c > 0 ? JText::sprintf('COM_COURSES_STUDENTS_SAVED', $c) : null)
+				JText::_('COM_COURSES_SAVED')
 			);
 			return;
 		}
@@ -363,17 +297,20 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 	 *
 	 * @return	void
 	 */
-	public function removeTask()
+	public function deleteTask()
 	{
 		// Check for request forgeries
 		JRequest::checkToken() or jexit('Invalid Token');
 
 		// Incoming
 		$ids = JRequest::getVar('id', array());
-		$ids = (!is_array($ids) ? array($ids) : $ids);
-
 		$offering_id = JRequest::getInt('offering', 0);
-		$section_id  = JRequest::getInt('section', 0);
+
+		// Get the single ID we're working with
+		if (!is_array($ids))
+		{
+			$ids = array();
+		}
 
 		$num = 0;
 
@@ -382,8 +319,8 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 		{
 			foreach ($ids as $id)
 			{
-				// Load the student record
-				$model = CoursesModelStudent::getInstance($id, null, null, null); //, $offering->get('course_id'), $offering_id, $section_id);
+				// Load the course page
+				$model = CoursesModelMember::getInstance($id);
 
 				// Ensure we found the course info
 				if (!$model->exists())
@@ -391,11 +328,27 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 					continue;
 				}
 
+				$data = json_encode($model);
+
 				// Delete course
 				if (!$model->delete())
 				{
-					JFactory::getApplication()->enqueueMessage(JText::sprintf('COM_COURSES_ERROR_UNABLE_TO_REMOVE_STUDENT', $model->get('user_id'), $model->get('section_id')), 'error');
-					continue;
+					JError::raiseError(500, JText::_('Unable to delete member'));
+					return;
+				}
+
+				// Log the course approval
+				$log = new CoursesTableLog($this->database);
+				$log->scope_id  = $id;
+				$log->scope     = 'section_member';
+				$log->user_id   = $this->juser->get('id');
+				$log->timestamp = date('Y-m-d H:i:s', time());
+				$log->action    = 'offering_deleted';
+				$log->actor_id  = $this->juser->get('id');
+				$log->comment   = $data;
+				if (!$log->store())
+				{
+					$this->setError($log->getError());
 				}
 
 				$num++;
@@ -404,8 +357,8 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 
 		// Redirect back to the courses page
 		$this->setRedirect(
-			'index.php?option=' . $this->_option . '&controller=' . $this->_controller . ($offering_id ? '&offering=' . $offering_id : '') . ($section_id ? '&section=' . $section_id : ''),
-			($num > 0 ? JText::sprintf('COM_COURSES_STUDENTS_REMOVED', $num) : null)
+			'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&offering=' . $offering_id . '&section=' . $section_id,
+			JText::sprintf('%s Item(s) removed.', $num)
 		);
 	}
 
@@ -423,55 +376,4 @@ class CoursesControllerStudents extends \Hubzero\Component\AdminController
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller . ($offering_id ? '&offering=' . $offering_id : '') . ($section_id ? '&section=' . $section_id : '')
 		);
 	}
-
-	/**
-	 * Save students info as CSV file
-	 *
-	 * @return	void
-	 */
-	public function csvTask()
-	{
-		// Get configuration
-		$app = JFactory::getApplication();
-		$config = JFactory::getConfig();
-
-		$this->view->filters['offering']    = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.offering',
-			'offering',
-			0
-		);
-		$this->view->filters['section_id']    = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.section',
-			'section',
-			0
-		);
-
-		$this->view->offering = CoursesModelOffering::getInstance($this->view->filters['offering']);
-		$this->view->filters['offering_id'] = $this->view->filters['offering'];
-		$this->view->course = CoursesModelCourse::getInstance($this->view->offering->get('course_id'));
-
-		if (!$this->view->filters['offering_id'])
-		{
-			$this->view->filters['offering_id'] = null;
-		}
-		if (!$this->view->filters['section_id'])
-		{
-			$this->view->filters['section_id'] = null;
-		}
-		$this->view->filters['student'] = 1;
-
-		$tbl = new CoursesTableMember($this->database);
-
-		$this->view->rows = $tbl->find($this->view->filters); //$this->view->offering->students($this->view->filters);
-		if ($this->view->rows)
-		{
-			foreach ($this->view->rows as $key => $row)
-			{
-				$this->view->rows[$key] = new CoursesModelStudent($row);
-			}
-		}
-
-		// Output the CSV
-		$this->view->display();
-	}
 }
