@@ -34,90 +34,83 @@ defined('_JEXEC') or die('Restricted access');
 /**
  *
  * Course Units table class
- *
+ * 
  */
 class CoursesTableUnit extends JTable
 {
 	/**
 	 * ID, primary key for course units table
-	 *
+	 * 
 	 * @var int(11)
 	 */
 	var $id = NULL;
 
 	/**
 	 * Course instance id of this unit (references #__course_instances.id)
-	 *
+	 * 
 	 * @var int(11)
 	 */
 	var $offering_id = NULL;
 
 	/**
 	 * Alias
-	 *
+	 * 
 	 * @var varchar(255)
 	 */
 	var $alias = NULL;
 
 	/**
 	 * Unit title
-	 *
+	 * 
 	 * @var varchar(255)
 	 */
 	var $title = NULL;
 
 	/**
 	 * Unit description
-	 *
+	 * 
 	 * @var longtext
 	 */
 	var $description = NULL;
 
 	/**
 	 * Ordering
-	 *
+	 * 
 	 * @var int(11)
 	 */
 	var $ordering = NULL;
 
 	/**
 	 * Start date for unit
-	 *
+	 * 
 	 * @var date
 	 */
 	//var $start_date = NULL;
 
 	/**
 	 * End date for unit
-	 *
+	 * 
 	 * @var date
 	 */
 	//var $end_date = NULL;
 
 	/**
 	 * Created date for unit
-	 *
+	 * 
 	 * @var datetime
 	 */
 	var $created = NULL;
 
 	/**
 	 * Who created the unit (reference #__users.id)
-	 *
+	 * 
 	 * @var int(11)
 	 */
 	var $created_by = NULL;
 
-	/**
-	 * tinyint(2)
-	 *
-	 * @var integer
-	 */
-	var $state = NULL;
-
 	/**
 	 * Contructor method for JTable class
-	 *
+	 * 
 	 * @param  database object
 	 * @return void
 	 */
@@ -129,34 +122,29 @@ class CoursesTableUnit extends JTable
 	/**
 	 * Populate the current object with a database record if found
 	 * Accepts either an alias or an ID
-	 *
+	 * 
 	 * @param      mixed $oid Unique ID or alias of object to retrieve
 	 * @return     boolean True on success
 	 */
-	public function load($oid=NULL, $offering_id=null)
+	public function load($oid=NULL)
 	{
-		if (empty($oid))
+		if (empty($oid)) 
 		{
 			return false;
 		}
 
-		if (is_numeric($oid))
+		if (is_numeric($oid)) 
 		{
 			return parent::load($oid);
 		}
 
-		$sql  = "SELECT * FROM $this->_tbl WHERE `alias`=" . $this->_db->Quote($oid);
-		if ($offering_id)
-		{
-			$sql .= " AND `offering_id`=" . $this->_db->Quote($offering_id);
-		}
-		$sql .= " AND `state`!=2 LIMIT 1";
+		$sql  = "SELECT * FROM $this->_tbl WHERE `alias`='$oid' LIMIT 1";
 		$this->_db->setQuery($sql);
-		if ($result = $this->_db->loadAssoc())
+		if ($result = $this->_db->loadAssoc()) 
 		{
 			return $this->bind($result);
-		}
-		else
+		} 
+		else 
 		{
 			$this->setError($this->_db->getErrorMsg());
 			return false;
@@ -165,7 +153,7 @@ class CoursesTableUnit extends JTable
 
 	/**
 	 * Override the check function to do a little input cleanup
-	 *
+	 * 
 	 * @return return true
 	 */
 	public function check()
@@ -178,7 +166,7 @@ class CoursesTableUnit extends JTable
 		}
 
 		$this->title = trim($this->title);
-		if (!$this->title)
+		if (!$this->title) 
 		{
 			$this->setError(JText::_('Please provide a title.'));
 			return false;
@@ -189,20 +177,16 @@ class CoursesTableUnit extends JTable
 			$this->alias = strtolower($this->title);
 		}
 		$this->alias = preg_replace("/[^a-zA-Z0-9\-_]/", '', $this->alias);
-		$this->makeAliasUnique();
 
 		if (!$this->id)
 		{
-			$juser = JFactory::getUser();
-			$this->created = JFactory::getDate()->toSql();
+			$juser =& JFactory::getUser();
+			$this->created = date('Y-m-d H:i:s', time());
 			$this->created_by = $juser->get('id');
 
-			$this->state = ($this->state) ? $this->state : 1;
-
-			if (!$this->ordering)
+			if(!$this->ordering)
 			{
 				$this->ordering = $this->getHighestOrdering($this->offering_id);
-				$this->ordering = (!$this->ordering) ? 1 : $this->ordering;
 			}
 		}
 
@@ -211,34 +195,26 @@ class CoursesTableUnit extends JTable
 
 	/**
 	 * Build query method
-	 *
+	 * 
 	 * @param  array $filters
 	 * @return $query database query
 	 */
 	private function _buildQuery($filters=array())
 	{
-		$query = " FROM $this->_tbl AS cu
+		$query = " FROM $this->_tbl AS cu 
 					LEFT JOIN #__courses_offering_section_dates AS sd ON sd.scope='unit' AND sd.scope_id=cu.id";
 
-		if (isset($filters['section_id']) && $filters['section_id'])
-		{
-			$query .= " AND sd.section_id=" . $this->_db->Quote($filters['section_id']);
-		}
-
 		$where = array();
 
-		if (isset($filters['offering_id']) && $filters['offering_id'])
+		if (isset($filters['offering_id']) && $filters['offering_id']) 
 		{
 			$where[] = "cu.offering_id=" . $this->_db->Quote($filters['offering_id']);
 		}
-		if (isset($filters['state']) && $filters['state'] >= 0)
+
+		if (isset($filters['search']) && $filters['search']) 
 		{
-			$where[] = "cu.state=" . $this->_db->Quote($filters['state']);
-		}
-		if (isset($filters['search']) && $filters['search'])
-		{
-			$where[] = "(LOWER(cu.alias) LIKE " . $this->_db->quote('%' . strtolower($filters['search']) . '%') . "
-					OR LOWER(cu.title) LIKE " . $this->_db->quote('%' . strtolower($filters['search']) . '%') . ")";
+			$where[] = "(LOWER(cu.alias) LIKE '%" . $this->_db->getEscaped(strtolower($filters['search'])) . "%' 
+					OR LOWER(cu.title) LIKE '%" . $this->_db->getEscaped(strtolower($filters['search'])) . "%')";
 		}
 
 		if (count($where) > 0)
@@ -251,7 +227,7 @@ class CoursesTableUnit extends JTable
 
 	/**
 	 * Get a count of course offering units
-	 *
+	 * 
 	 * @param  array $filters
 	 * @return object Return course units
 	 */
@@ -266,13 +242,13 @@ class CoursesTableUnit extends JTable
 
 	/**
 	 * Get an object list of course offering units
-	 *
+	 * 
 	 * @param  array $filters
 	 * @return object Return course units
 	 */
 	public function find($filters=array())
 	{
-		$query  = "SELECT DISTINCT cu.*, sd.publish_up, sd.publish_down, sd.section_id";
+		$query  = "SELECT cu.*, sd.publish_up, sd.publish_down";
 		$query .= $this->_buildQuery($filters);
 
 		if (!empty($filters['start']) && !empty($filters['limit']))
@@ -288,36 +264,14 @@ class CoursesTableUnit extends JTable
 
 	/**
 	 * Get the last page in the ordering
-	 *
+	 * 
 	 * @param      string  $offering_id
 	 * @return     integer
 	 */
 	public function getHighestOrdering($offering_id)
 	{
-		$sql = "SELECT MAX(ordering)+1 FROM $this->_tbl WHERE offering_id=" . $this->_db->Quote(intval($offering_id));
+		$sql = "SELECT max(ordering)+1 FROM $this->_tbl WHERE offering_id=" . $this->_db->Quote(intval($offering_id));
 		$this->_db->setQuery($sql);
 		return $this->_db->loadResult();
 	}
-
-	/**
-	 * Return a unique alias based on given alias
-	 *
-	 * @return     integer
-	 */
-	private function makeAliasUnique()
-	{
-		$sql = "SELECT alias from $this->_tbl WHERE `offering_id`=" . $this->_db->Quote(intval($this->offering_id)) . " AND `id`!=" . $this->_db->Quote(intval($this->id));
-		$this->_db->setQuery($sql);
-		$result = $this->_db->loadResultArray();
-
-		$original_alias = $this->alias;
-
-		if ($result)
-		{
-			for ($i=1; in_array($this->alias, $result); $i++)
-			{
-				$this->alias = $original_alias . $i;
-			}
-		}
-	}
 }
\ No newline at end of file
